/*
Section:  1) 0NF to 1NF
Script:   3) Getting Data Into 1NF
Basics:   Our first attempt at data loading was easy but
			led to processing nightmares.  We are now going
			to turn this structure into a first normal form model.
Notes:    
*/

/*
This time around, we're going to model entities and attributes.
This means our final product might NOT look like the spreadsheet.
We want to keep at least the data points we have, but could also
include other points if we need them.
For this 1NF model, we'll stick to using natural keys.

LineupMember
	- Year
	- Name
	- IsSessionOnly
	- (Set of instruments)

Instrument
	- Name

Song
	- Year
	- Type { Studio, Live }
	- AlbumName
	- Label
	- TrackNumber	<-- New attribute!
	- SongName
	- (Set of members)

ProjeKctMember
	- Year
	- Name
	- (Set of instruments)

ProjeKctTrack
	- Year
	- Type { Studio, Live }
	- ProjeKctName
	- AlbumName
	- TrackNumber	<-- New attribute!
	- TrackName
	- (Set of projeKct members)

Each time we see "(Set of...)" we have uncovered a
many-to-many relationship and need to create a junction table.

TO DO:
1)  Figure out candidate keys for each entity.
2)  Use those candidate keys to create the junction tables
*/

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'LineupMember'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	CREATE TABLE [1NF].[LineupMember]
	(
		[Year] INT NOT NULL,
		[Name] VARCHAR(40) NOT NULL,
		[IsSessionOnly] BIT NOT NULL
	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'Instrument'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	CREATE TABLE [1NF].[Instrument]
	(
		[Name] VARCHAR(40) NOT NULL
	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'LineupMemberXInstrument'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	--TODO:  fill this in with the appropriate primary keys!
	CREATE TABLE [1NF].[LineupMemberXInstrument]
	(

	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'Song'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	CREATE TABLE [1NF].[Song]
	(
		[Year] INT NOT NULL,
		[Type] VARCHAR(6) NOT NULL,
		[AlbumName] VARCHAR(120) NOT NULL,
		[Label] VARCHAR(50) NOT NULL,
		[TrackNumber] TINYINT NOT NULL,
		[SongName] VARCHAR(120) NOT NULL
	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'LineupMemberXSong'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	--TODO:  fill this in with the appropriate primary keys!
	CREATE TABLE [1NF].[LineupMemberXSong]
	(

	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'ProjeKctMember'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	CREATE TABLE [1NF].[ProjeKctMember]
	(
		[Year] INT NOT NULL,
		[Name] VARCHAR(40) NOT NULL
	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'ProjeKctMemberXInstrument'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	--TODO:  fill this in with the appropriate primary keys!
	CREATE TABLE [1NF].[ProjeKctMemberXInstrument]
	(

	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'ProjeKctTrack'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	CREATE TABLE [1NF].[ProjeKctTrack]
	(
		[Year] INT NOT NULL,
		[Type] VARCHAR(6) NOT NULL,
		[ProjeKctName] VARCHAR(120) NOT NULL,
		[AlbumName] VARCHAR(120) NOT NULL,
		[Label] VARCHAR(50) NOT NULL,
		[TrackNumber] TINYINT NOT NULL,
		[TrackName] VARCHAR(120) NOT NULL
	);
END
GO

IF NOT EXISTS
(
	SELECT 1
	FROM sys.tables
	WHERE
		name = 'ProjeKctMemberXProjeKctTrack'
		AND OBJECT_SCHEMA_NAME(object_id) = '1NF'
)
BEGIN
	--TODO:  fill this in with the appropriate primary keys!
	CREATE TABLE [1NF].[ProjeKctMemberXProjeKctTrack]
	(

	);
END
GO
